@@ -31,30 +31,36 @@ opening: dict[str, str] = {}
 # """
 
 opening["estuda"] = r"""
-------- O modelo de avaliação utiliza 3 critérios --------
+▄▖         ▐▘      ▘                 ▐▘▘▜ ▗       ▄▖
+▌ ▛▌▛▛▌▛▌  ▜▘▌▌▛▌▛▘▌▛▌▛▌▀▌▛▛▌  ▛▌▛▘  ▜▘▌▐ ▜▘▛▘▛▌▛▘▗▘
+▙▖▙▌▌▌▌▙▌  ▐ ▙▌▌▌▙▖▌▙▌▌▌█▌▌▌▌  ▙▌▄▌  ▐ ▌▐▖▐▖▌ ▙▌▄▌▗ 
+                                                    
+Os botões de 1 a 4 habilitam os filtros de exibição.
+- Gráficos: mostra os gráficos de acompanhamento.
+- Trilhas : mostra a barra lateral de trilhas de habilidades.
+- Tópicos : mostra as missões (recomendadas ou todas).
+- Tarefas : esconde as atividades já concluídas.
+▄▖         ▐▘      ▘                ▗   ▄▖
+▌ ▛▌▛▛▌▛▌  ▜▘▌▌▛▌▛▘▌▛▌▛▌▀▌  ▀▌  ▛▌▛▌▜▘▀▌▗▘
+▙▖▙▌▌▌▌▙▌  ▐ ▙▌▌▌▙▖▌▙▌▌▌█▌  █▌  ▌▌▙▌▐▖█▌▗ 
+                                          
+- Após fazer ou refazer uma atividade, você usa o comando de pontuar,
+usando o 'p' ou o '.', e informe como fez a atividade.
+       ⢀⣠⣤⣴⡾⠻⢶⣤⡀ 
+     ⢀⣶⠟⠉⠉    ⠉⢷⡄  - Quanto da atividade foi entregue?
+   ⠉⢿⣿⣿⣿⠏⠈⢿⣿⣿⣿⡿⢟⣿    - Se houver testes, isso será calculado automaticamente
+    ⢸⡏ ⢠⣀ ⢀⡤   ⢨⣿  - Quanto conseguiu fazer antes de consultar ajuda?
+    ⠸⣿⡀ ⠉⠉⠉  ⢀⣠⡾⠃  - Se utilizou alguma ajuda, qual foi?
+     ⠈⠻⠷⠶⣶⡶⠾⠿⠛⠉      - Humana? Quem?
+ ⢀⡀     ⢀⣿           - IA? Qual? Como?
+⠿⢿⣧⡀    ⣸⣟           - Guiada seguindo aula ou vídeo?
+  ⠘⢿⡄ ⣠⡾⢻⣿⣄          - Outros? Pesquisando na documentação ou exemplos?
+    ⢿⣴⡟ ⢸⡏⠹⣧       - Qual tempo estimado em minutos de estudo + implementação?
+    ⠈⠛  ⢸⣟ ⠹⣧    
+- Você pode e deve refazer a atividade do zero quantas vezes quiser e
+reavaliar e melhorar sua nota.
 
-- Cobertura: quanto da atividade foi entregue\?
-  - Se houver testes, isso será calculado automaticamente
-- Abordagem: como foi a última execução da atividade\?
-  - Copiar, ChatGpt, Copilot, Aula, Monitoria, Sozinho
-- Autonomia: se refizer a atividade sozinho e SEM CONSULTA,
-    quanto dela você se sente confiante para fazer\?
 
-Cobertura: (  fiz nada ) 0 1 ... 9 ✓ (entreguei tudo)
-Abordagem: (muita ajuda) x E D C B A (nenhum suporte)
-Autonomia: (não aprendi) x ▁ ▂ ▃ ▅ █ (refaço sozinho)
-
- ,`````.          __||||___       
-' Estuda`,       /_  ___   \      
-'miserável`.    /@ \/@  \   \     
- ` , . , '  `.. \__/\___/   /     
-                 \_\/______/      
-                 /     /\\\\\     
-                |     |\\\\\\     
-                 \      \\\\\\    
-                  \______/\\\\    
-            _______ ||_||_______  
-           (______(((_(((______(@)
 """[1:]
 
 # opening["alien4"] = r"""
